==> igniteui-webcomponents-maps-4.7.2.tgz: package/esm2015/lib/GeographicMarkerSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicMapSeriesHost } from "./GeographicMapSeriesHost";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { DataTemplate } from "igniteui-webcomponents-core";
import { Brush } from "igniteui-webcomponents-core";
import { runOn, delegateCombine, typeCast, enumGetBox, markType, markDep } from "igniteui-webcomponents-core";
import { MarkerSeries } from "igniteui-webcomponents-charts";
import { Defaults } from "igniteui-webcomponents-charts";
import { PropertyMetadata } from "igniteui-webcomponents-core";
import { DeviceUtils } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let GeographicMarkerSeries = /*@__PURE__*/ (() => {
    class GeographicMarkerSeries extends GeographicMapSeriesHost {
        constructor() {
            super();
            let a = this.t5;
            a.propertyUpdated = delegateCombine(a.propertyUpdated, runOn(this, this.ut));
        }
        qx() {
            return this.uu;
        }
        s1() {
            return this.u7;
        }
        s2() {
            return this.u8;
        }
        ht() {
            return this.ug;
        }
        ky() {
            let a = typeCast(MarkerSeries.$, this.t5);
            if (a == null) {
                return "Unknown";
            }
            return a.ky();
        }
        ut(a, b) {
            let c = typeCast(MarkerSeries.$, this.t5);
            if (c == null) {
                return;
            }
            if (b.propertyName == "ActualMarkerTemplate") {
                this.uu = c.uw;
            }
            else if (b.propertyName == "ActualMarkerOutline") {
                this.u8 = c.vd;
            }
            else if (b.propertyName == "ActualMarkerBrush") {
                this.u7 = c.vc;
            }
        }
        pa(a, b, c, d) {
            super.pa(a, b, c, d);
            switch (b) {
                case GeographicMarkerSeries.$$p[3]:
                    this.t5.ve = this.u9;
                    break;
                case GeographicMarkerSeries.$$p[6]:
                    this.t5.vf = this.va;
                    break;
                case GeographicMarkerSeries.$$p[5]:
                    this.t5.t9 = this.ue;
                    break;
                case GeographicMarkerSeries.$$p[4]:
                    this.t5.t5 = this.ud;
                    break;
                case GeographicMarkerSeries.$$p[9]:
                    this.t5.uc = this.uf;
                    break;
                case GeographicMarkerSeries.$$p[7]:
                    this.t5.uy = this.uv;
                    break;
                case GeographicMarkerSeries.$$p[8]:
                    this.t5.uh = this.ug;
                    break;
                case GeographicMarkerSeries.$$p[10]:
                    this.t5.w3 = this.uh;
                    break;
            }
        }
    }
    GeographicMarkerSeries.$t = /*@__PURE__*/ markType(GeographicMarkerSeries, 'GeographicMarkerSeries', GeographicMapSeriesHost.$);
    GeographicMarkerSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, GeographicMarkerSeries, 'raisePropertyChanged', ['ActualMarkerBrush:u7:uw', [Brush.$], 'ActualMarkerOutline:u8:ux', [Brush.$], 'ActualMarkerTemplate:uu:uy', [DataTemplate.$, null], 'MarkerBrush:u9:uz', [Brush.$], 'MarkerFillMode:ud:u0', [MarkerFillMode_$type, /*@__PURE__*/ enumGetBox(MarkerFillMode_$type, 0)], 'MarkerOutlineMode:ue:u1', [MarkerOutlineMode_$type, /*@__PURE__*/ enumGetBox(MarkerOutlineMode_$type, 0)], 'MarkerOutline:va:u2', [Brush.$], 'MarkerTemplate:uv:u3', [DataTemplate.$, null], 'MarkerThickness:ug:u4', [1, /*@__PURE__*/ DeviceUtils.g(2)], 'MarkerType:uf:u5', [MarkerType_$type, /*@__PURE__*/ enumGetBox(MarkerType_$type, Defaults.e)], 'MaximumMarkers:uh:u6', [1, 400]]);
    return GeographicMarkerSeries;
})();

==> igniteui-webcomponents-maps-5.4.1.tgz: package/esm2015/lib/GeographicMarkerSeries.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { GeographicMapSeriesHost } from "./GeographicMapSeriesHost";
import { MarkerType_$type } from "igniteui-webcomponents-charts";
import { DependencyProperty } from "igniteui-webcomponents-core";
import { MarkerOutlineMode_$type } from "igniteui-webcomponents-charts";
import { MarkerFillMode_$type } from "igniteui-webcomponents-charts";
import { DataTemplate } from "igniteui-webcomponents-core";
import { Brush } from "igniteui-webcomponents-core";
import { runOn, delegateCombine, typeCast, enumGetBox, markType, markDep } from "igniteui-webcomponents-core";
import { MarkerSeries } from "igniteui-webcomponents-charts";
import { Defaults } from "igniteui-webcomponents-charts";
import { PropertyMetadata } from "igniteui-webcomponents-core";
import { DeviceUtils } from "igniteui-webcomponents-core";
/**
 * @hidden
 */
export let GeographicMarkerSeries = /*@__PURE__*/ (() => {
    class GeographicMarkerSeries extends GeographicMapSeriesHost {
        constructor() {
            super();
            let a = this.w2;
            a.propertyUpdated = delegateCombine(a.propertyUpdated, runOn(this, this.xq));
        }
        s1() {
            return this.xr;
        }
        vn() {
            return this.x4;
        }
        vo() {
            return this.x5;
        }
        io() {
            return this.xd;
        }
        ma() {
            let a = typeCast(MarkerSeries.$, this.w2);
            if (a == null) {
                return "Unknown";
            }
            return a.ma();
        }
        xq(a, b) {
            let c = typeCast(MarkerSeries.$, this.w2);
            if (c == null) {
                return;
            }
            if (b.propertyName == "ActualMarkerTemplate") {
                this.xr = c.x2;
            }
            else if (b.propertyName == "ActualMarkerOutline") {
                this.x5 = c.yk;
            }
            else if (b.propertyName == "ActualMarkerBrush") {
                this.x4 = c.yj;
            }
        }
        ra(a, b, c, d) {
            super.ra(a, b, c, d);
            switch (b) {
                case GeographicMarkerSeries.$$p[3]:
                    this.w2.yl = this.x6;
                    break;
                case GeographicMarkerSeries.$$p[6]:
                    this.w2.ym = this.x7;
                    break;
                case GeographicMarkerSeries.$$p[5]:
                    this.w2.w6 = this.xb;
                    break;
                case GeographicMarkerSeries.$$p[4]:
                    this.w2.w2 = this.xa;
                    break;
                case GeographicMarkerSeries.$$p[9]:
                    this.w2.xc = this.xc;
                    break;
                case GeographicMarkerSeries.$$p[7]:
                    this.w2.x4 = this.xs;
                    break;
                case GeographicMarkerSeries.$$p[8]:
                    this.w2.xl = this.xd;
                    break;
                case GeographicMarkerSeries.$$p[10]:
                    this.w2.aab = this.xe;
                    break;
            }
        }
    }
    GeographicMarkerSeries.$t = /*@__PURE__*/ markType(GeographicMarkerSeries, 'GeographicMarkerSeries', GeographicMapSeriesHost.$);
    GeographicMarkerSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, GeographicMarkerSeries, 'raisePropertyChanged', ['ActualMarkerBrush:x4:xt', [Brush.$], 'ActualMarkerOutline:x5:xu', [Brush.$], 'ActualMarkerTemplate:xr:xv', [DataTemplate.$, null], 'MarkerBrush:x6:xw', [Brush.$], 'MarkerFillMode:xa:xx', [MarkerFillMode_$type, /*@__PURE__*/ enumGetBox(MarkerFillMode_$type, 0)], 'MarkerOutlineMode:xb:xy', [MarkerOutlineMode_$type, /*@__PURE__*/ enumGetBox(MarkerOutlineMode_$type, 0)], 'MarkerOutline:x7:xz', [Brush.$], 'MarkerTemplate:xs:x0', [DataTemplate.$, null], 'MarkerThickness:xd:x1', [1, /*@__PURE__*/ DeviceUtils.g(2)], 'MarkerType:xc:x2', [MarkerType_$type, /*@__PURE__*/ enumGetBox(MarkerType_$type, Defaults.e)], 'MaximumMarkers:xe:x3', [1, 400]]);
    return GeographicMarkerSeries;
})();
